@@ -2008,7 +2008,9 @@ aisleriot_window_state_event (GtkWidget *widget,
                               GdkEventWindowState *event)
 {
   AisleriotWindow *window = AISLERIOT_WINDOW (widget);
+#ifndef HAVE_HILDON
   AisleriotWindowPrivate *priv = window->priv;
+#endif
 
   if (event->changed_mask & (GDK_WINDOW_STATE_FULLSCREEN | GDK_WINDOW_STATE_MAXIMIZED)) {
     gboolean is_fullscreen, is_maximised;
@@ -2304,7 +2306,7 @@ aisleriot_window_init (AisleriotWindow *window)
         "<toolitem action='Deal'/>"
         "<toolitem action='Hint'/>"
 #ifndef HAVE_MAEMO
-        "<toolitem action='LeaveFullscreen'/>"
+        "<toolitem action='Fullscreen'/>"
 #endif
 #ifdef ENABLE_DEBUG_UI
         "<toolitem action='DebugGameFirst'/>"
